/****** axuucp/rn-genactive **************************************************
*
*   NAME
*	rn-genactive - Update news active file
*
*   SYNOPSIS
*	rx rn-genactive.rexx
*
*   DESCRIPTION
*	For each group listed in /usr/spool/news/NewsGroups the .lowest and
*	.next file will examined and the contents of the active file will be
*	printed to stdout
*
*   FORMAT OF THE ACTIVE FILE
*	Space seperated fields:  group highest lowest flag
*	(highest and lowest must have at least 5 digits)
*
*	legal flags are:
*		y  normal unmoderated group
*		n  like y, but local postings disallowed
*		m  normal moderated group
*		x  locally disallowed group
*		=  (followed by the real group) link
*
*   AUTHOR
*	Tobias Ferber <tf@ganymed.hall.sub.org>
*
******************************************************************************
*
*/

axnews     = axconfig("news")
newsgroups = axconfig("newsgroupfile")

call open('fp',newsgroups)

do until eof('fp')
  gname= word(readln('fp'),1)
  if words(gname) > 0 then do
    gdir= axnews || translate(gname,'/','.')
    call open('tmp',gdir'/.lowest'); _lowest = readln('tmp'); call close('tmp')
    call open('tmp',gdir'/.next');   _next   = readln('tmp'); call close('tmp')

    say gname right(_next-1,8,'0') right(_lowest,8,'0') 'y'
    end
  end

call close('fp')
exit


/*@<axconfig>*/

/* get an AXsh configuration value */

axconfig: procedure
  tempfile = "T:axconfig." || pragma('Id')
  rc_index  = "AXsh:rexx/rc.index"
  var_val=""; var_file=""; var_defval="";

  parse upper arg var_name
  if left(var_name,1) ~= '%' then var_name = '%'var_name
  if right(var_name,1) ~= ':' then var_name = var_name':'

  if open('idx',rc_index,'Read') then do
    do until (eof('idx') | (var_file~=''))
      str= translate(readln('idx'),' ',d2c(9))
      if words(str) > 0 then do
        parse var str vname ' ' fname '"' defval '"'
        if upper(vname) = var_name then do
          var_file= strip(fname,'B',' 'd2c(9))
          var_defval= defval
          end
        end
      end
    call close('idx')
    end
  else say 'Could not read "'rc_index'"'

  if words(var_file) > 0 then do
    if open('rc',var_file,'Read') then do
      do until (eof('rc') | (var_val~=''))
        str= translate(readln('rc'),' ',d2c(9))
        if upper(word(str,1)) = var_name then var_val = strip(readln('rc'),'B',' 'd2c(9))
        end
      call close('rc')
      end
    else say 'Could not examine "'var_file'" for' var_name
    end
  else do
    if words(var_defval) > 0 then var_val= var_defval
    else say 'No such config variable:' var_name
    end

  return var_val

