/****** axuucp/rn-rmgroup ****************************************************
*
*   NAME
*	rn-rmgroup - Remove a newsgroup from the system
*
*   SYNOPSIS
*	rx rn-rmgroup.rexx [group]
*
*   DESCRIPTION
*	This script removes a newsgroup from the AXsh news system.
*	All articles will be deleted, the newsgroup path will be removed
*	and the group will be removed from the /usr/spool/newsgroups file.
*
*   AUTHOR
*	Tobias Ferber <tf@ganymed.hall.sub.org>
*
******************************************************************************
*
*/

axnews = axconfig("news")
newsgroups = axconfig("newsgroupfile")
tempfile = "T:rn-rmgroup." || pragma('Id')

group_name = arg(1)
group_path = axnews || translate(group_name,'/','.')

address command 'agrep -c -i "^'group_name'" <' newsgroups '>' tempfile
call open('tmp',tempfile); g= strip(readln('tmp')); call close('tmp')

select
  when g=1 then do
    say 'Removing' group_name 'from "'newsgroups'"'
    address command 'Rename QUIET' newsgroups newsgroups'_'
    address command 'agrep -v -i "^'group_name'" <' newsgroups'_ >' newsgroups
    address command 'Delete QUIET' newsgroups'_'

    if exists(group_path) then do
      say 'Deleting all articles "'group_path'"'
      address command 'Protect' group_path 'RWED ALL QUIET'
      address command 'Delete' group_path 'ALL QUIET'
      end
    end

  when g>1 then say group_name 'is ambiguous in "'newsgroups'" ('g 'groups)'
  otherwise group_name 'not listed in "'newsgroups'"'
  end

exit 0


/*@<axconfig>*/

/* get an AXsh configuration value */

axconfig: procedure
  tempfile = "T:axconfig." || pragma('Id')
  rc_index  = "AXsh:rexx/rc.index"
  var_val=""; var_file=""; var_defval="";

  parse upper arg var_name
  if left(var_name,1) ~= '%' then var_name = '%'var_name
  if right(var_name,1) ~= ':' then var_name = var_name':'

  if open('idx',rc_index,'Read') then do
    do until (eof('idx') | (var_file~=''))
      str= translate(readln('idx'),' ',d2c(9))
      if words(str) > 0 then do
        parse var str vname ' ' fname '"' defval '"'
        if upper(vname) = var_name then do
          var_file= strip(fname,'B',' 'd2c(9))
          var_defval= defval
          end
        end
      end
    call close('idx')
    end
  else say 'Could not read "'rc_index'"'

  if words(var_file) > 0 then do
    if open('rc',var_file,'Read') then do
      do until (eof('rc') | (var_val~=''))
        str= translate(readln('rc'),' ',d2c(9))
        if upper(word(str,1)) = var_name then var_val = strip(readln('rc'),'B',' 'd2c(9))
        end
      call close('rc')
      end
    else say 'Could not examine "'var_file'" for' var_name
    end
  else do
    if words(var_defval) > 0 then var_val= var_defval
    else say 'No such config variable:' var_name
    end

  return var_val

